@@ -2,8 +2,14 @@ import logging
 import os
 import shortuuid
 
+from dvc.stage import Stage
 from dvc.config import Config
-from dvc.exceptions import NotDvcRepoError, UrlNotDvcRepoError
+from dvc.exceptions import (
+    NotDvcRepoError,
+    UrlNotDvcRepoError,
+    GetDVCFileError,
+    OutputNotFoundError,
+)
 from dvc.path_info import PathInfo
 from dvc.external_repo import external_repo
 from dvc.state import StateNoop
@@ -17,6 +23,9 @@ logger = logging.getLogger(__name__)
 def get(url, path, out=None, rev=None):
     out = out or os.path.basename(urlparse(path).path)
 
+    if Stage.is_valid_filename(out):
+        raise GetDVCFileError()
+
     # Creating a directory right beside the output to make sure that they
     # are on the same filesystem, so we could take the advantage of
     # reflink and/or hardlink. Not using tempfile.TemporaryDirectory
@@ -55,5 +64,7 @@ def get(url, path, out=None, rev=None):
 
     except NotDvcRepoError:
         raise UrlNotDvcRepoError(url)
+    except OutputNotFoundError:
+        raise OutputNotFoundError(path)
     finally:
         remove(tmp_dir)
